@@ -9,7 +9,7 @@ use Schedule::Activity::Message;
 use Schedule::Activity::Node;
 use Schedule::Activity::NodeFilter;
 
-our $VERSION='0.2.1';
+our $VERSION='0.2.2';
 
 sub new {
 	my ($ref,%opt)=@_;
@@ -371,7 +371,7 @@ sub schedule {
 			my $annotation=Schedule::Activity::Annotation->new(%$note);
 			foreach my $note ($annotation->annotate(@{$res{activities}})) {
 				my ($message,$mobj)=Schedule::Activity::Message->new(message=>$$note[1]{message},names=>$$self{config}{messages}//{})->random();
-				my %node=(message=>$message);
+				my %node=(%{$mobj//{}},message=>$message);
 				if($$note[1]{annotations}) { $node{annotations}=$$note[1]{annotations} }
 				push @schedule,[$$note[0],\%node,@$note[2..$#$note]];
 			}
@@ -388,6 +388,24 @@ sub schedule {
 	return %res;
 }
 
+sub computeAttributes {
+	my ($self,@activities)=@_;
+	$self->_attr()->push();
+	$self->_attr()->reset();
+	foreach my $event (sort {$$a[0]<=>$$b[0]} @activities) {
+		my ($tm,$node,$msg)=@$event;
+		if($$node{attributes}) {
+			while(my ($k,$v)=each %{$$node{attributes}}) {
+				$self->_attr()->change($k,%$v,tm=>$tm) } }
+		if(is_hashref($msg)) { while(my ($k,$v)=each %{$$msg{attributes}}) {
+			$self->_attr()->change($k,%$v,tm=>$tm);
+		} }
+	}
+	my %res=$self->_attr()->report();
+	$self->_attr()->pop();
+	return %res;
+}
+
 sub loadMarkdown {
 	my ($text)=@_;
 	my $list=qr/(?:\d+\.|[-*])/;
@@ -442,7 +460,7 @@ Schedule::Activity - Generate random activity schedules
 
 =head1 VERSION
 
-Version 0.2.1
+Version 0.2.2
 
 =head1 SYNOPSIS
 
@@ -714,6 +732,14 @@ Any attribute may be "fixed" in the log at their current value with the configur
 
 Attribute logging always occurs at the beginning and end of the completed schedule, so that all scheduled time affects the weighted average value calculation.  Activities may reset or fix attributes in their beginning or final node; the final node is only the "end of the activity" when C<tmavg=0>.
 
+=head2 Recomputation
+
+Any schedule of activities associated with the initial configuration can generate a standalone attribute report:
+
+  %attributes=$scheduler->computeAttributes(@activities)
+
+This permits manual modification of activities, merging across multiple scheduling runs, or merging of annotations (below) to materialize a final attribute report.  This does not affect the attributes within the C<$scheduler>.
+
 =head1 ANNOTATIONS
 
 A scheduling configuration may contain a list of annotations:
